@@ -1,6 +1,7 @@
 # arg_name ----
 ## Test 1: arg_name works ----
 test_that("arg_name Test 1: arg_name works", {
+  withr::local_options(lifecycle_verbosity = "quiet")
   expect_equal(arg_name(sym("a")), "a")
   expect_equal(arg_name(call("enquo", sym("a"))), "a")
   expect_error(arg_name("a"), "Could not extract argument name from")
@@ -27,7 +28,7 @@ test_that("convert_dtm_to_dtc Test 3: Error is thrown if dtm is not in correct f
 # filter_if ----
 ## Test 4: Input is returned as is if filter is NULL ----
 test_that("filter_if Test 4: Input is returned as is if filter is NULL", {
-  input <- tibble::tribble(
+  input <- dplyr::tribble(
     ~USUBJID, ~VSTESTCD, ~VSSTRESN,
     "P01",    "WEIGHT",       80.9,
     "P01",    "HEIGHT",      189.2
@@ -44,7 +45,7 @@ test_that("filter_if Test 4: Input is returned as is if filter is NULL", {
 
 ## Test 5: Input is filtered if filter is not NULL ----
 test_that("filter_if Test 5: Input is filtered if filter is not NULL", {
-  input <- tibble::tribble(
+  input <- dplyr::tribble(
     ~USUBJID, ~VSTESTCD, ~VSSTRESN,
     "P01",    "WEIGHT",       80.9,
     "P01",    "HEIGHT",      189.2
